==> libopenmpt-0.5.41-pre.0+r24694.doc.tar.gz: libopenmpt-0.5.41-pre.0+r24694.doc/docs/libopenmpt__ext_8h.js <==
var libopenmpt__ext_8h =
[
    [ "LIBOPENMPT_EXT_C_INTERFACE_INTERACTIVE", "group__libopenmpt__ext__c.html#gacb3881b0a801d57c3e127f6b05173340", null ],
    [ "LIBOPENMPT_EXT_C_INTERFACE_PATTERN_VIS", "group__libopenmpt__ext__c.html#gac4ca910407ed5fc38164ffc61b470fab", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_GENERAL", "group__libopenmpt__ext__c.html#ga8d0952a39ada51bca93cc146a2581257", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_GLOBAL", "group__libopenmpt__ext__c.html#ga39268c4e1b39dbd711015dcf7803d0d1", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_PANNING", "group__libopenmpt__ext__c.html#ga30263b9490271ef742baea628d9914a7", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_PITCH", "group__libopenmpt__ext__c.html#ga57bcab6825fa9ea66372d886bd33b6ad", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_UNKNOWN", "group__libopenmpt__ext__c.html#ga4a28a223d6b8f5b3edc3f9cc74c520ea", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_VOLUME", "group__libopenmpt__ext__c.html#ga60d6664046f2de67ab3fc88cabf0089f", null ],
    [ "openmpt_module_ext", "group__libopenmpt__ext__c.html#gaefd83333cf6e40a0d4d3f62e34dfca5c", null ],
    [ "openmpt_module_ext_interface_interactive", "group__libopenmpt__ext__c.html#gac04b9e67a3c802c75be70f7b7199bc70", null ],
    [ "openmpt_module_ext_interface_pattern_vis", "group__libopenmpt__ext__c.html#gaf6fbe7e0a5cb4804cc19adedb9166e8d", null ],
    [ "openmpt_module_ext_create", "group__libopenmpt__ext__c.html#gadc0eaf6067b9a1bdfd04db9aaa22286a", null ],
    [ "openmpt_module_ext_create_from_memory", "group__libopenmpt__ext__c.html#gac6bacf019368fe78ebcc2511c15ae039", null ],
    [ "openmpt_module_ext_destroy", "group__libopenmpt__ext__c.html#ga737466596e917bd196c7b30496aad1b8", null ],
    [ "openmpt_module_ext_get_interface", "group__libopenmpt__ext__c.html#ga0275a35da407cd092232a20d3535c9e4", null ],
    [ "openmpt_module_ext_get_module", "group__libopenmpt__ext__c.html#gace3ad42bcb313134e6e13c4eb16ba333", null ]
];

==> libopenmpt-0.6.27-pre.0+r24693.doc.tar.gz: libopenmpt-0.6.27-pre.0+r24693.doc/docs/libopenmpt__ext_8h.js <==
var libopenmpt__ext_8h =
[
    [ "LIBOPENMPT_EXT_C_INTERFACE_INTERACTIVE", "group__libopenmpt__ext__c.html#gacb3881b0a801d57c3e127f6b05173340", null ],
    [ "LIBOPENMPT_EXT_C_INTERFACE_INTERACTIVE2", "group__libopenmpt__ext__c.html#ga6980beb4ff16a77f66362108d8677490", null ],
    [ "LIBOPENMPT_EXT_C_INTERFACE_PATTERN_VIS", "group__libopenmpt__ext__c.html#gac4ca910407ed5fc38164ffc61b470fab", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_GENERAL", "group__libopenmpt__ext__c.html#ga8d0952a39ada51bca93cc146a2581257", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_GLOBAL", "group__libopenmpt__ext__c.html#ga39268c4e1b39dbd711015dcf7803d0d1", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_PANNING", "group__libopenmpt__ext__c.html#ga30263b9490271ef742baea628d9914a7", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_PITCH", "group__libopenmpt__ext__c.html#ga57bcab6825fa9ea66372d886bd33b6ad", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_UNKNOWN", "group__libopenmpt__ext__c.html#ga4a28a223d6b8f5b3edc3f9cc74c520ea", null ],
    [ "OPENMPT_MODULE_EXT_INTERFACE_PATTERN_VIS_EFFECT_TYPE_VOLUME", "group__libopenmpt__ext__c.html#ga60d6664046f2de67ab3fc88cabf0089f", null ],
    [ "openmpt_module_ext", "group__libopenmpt__ext__c.html#gaefd83333cf6e40a0d4d3f62e34dfca5c", null ],
    [ "openmpt_module_ext_interface_interactive", "group__libopenmpt__ext__c.html#gafabf3ff72796b98b8e249ffee40ce38b", null ],
    [ "openmpt_module_ext_interface_interactive2", "group__libopenmpt__ext__c.html#ga356d304bf5ab293359f16a400fe8290e", null ],
    [ "openmpt_module_ext_interface_pattern_vis", "group__libopenmpt__ext__c.html#ga026116db72e4091a41919cd78a388c7d", null ],
    [ "openmpt_module_ext_create", "group__libopenmpt__ext__c.html#gadc0eaf6067b9a1bdfd04db9aaa22286a", null ],
    [ "openmpt_module_ext_create_from_memory", "group__libopenmpt__ext__c.html#gac6bacf019368fe78ebcc2511c15ae039", null ],
    [ "openmpt_module_ext_destroy", "group__libopenmpt__ext__c.html#ga737466596e917bd196c7b30496aad1b8", null ],
    [ "openmpt_module_ext_get_interface", "group__libopenmpt__ext__c.html#ga0275a35da407cd092232a20d3535c9e4", null ],
    [ "openmpt_module_ext_get_module", "group__libopenmpt__ext__c.html#gace3ad42bcb313134e6e13c4eb16ba333", null ]
];
